@@ -5,33 +5,26 @@ use Carp qw(croak);
 
 has minion => undef, weak => 1;
 
-sub broadcast    { croak 'Method "broadcast" not implemented by subclass' }
-sub dequeue      { croak 'Method "dequeue" not implemented by subclass' }
-sub enqueue      { croak 'Method "enqueue" not implemented by subclass' }
-sub fail_job     { croak 'Method "fail_job" not implemented by subclass' }
-sub finish_job   { croak 'Method "finish_job" not implemented by subclass' }
-sub history      { croak 'Method "history" not implemented by subclass' }
-sub list_jobs    { croak 'Method "list_jobs" not implemented by subclass' }
-sub list_locks   { croak 'Method "list_locks" not implemented by subclass' }
-sub list_workers { croak 'Method "list_workers" not implemented by subclass' }
-sub lock         { croak 'Method "lock" not implemented by subclass' }
-sub note         { croak 'Method "note" not implemented by subclass' }
-sub receive      { croak 'Method "receive" not implemented by subclass' }
-
-sub register_worker {
-  croak 'Method "register_worker" not implemented by subclass';
-}
-
-sub remove_job { croak 'Method "remove_job" not implemented by subclass' }
-sub repair     { croak 'Method "repair" not implemented by subclass' }
-sub reset      { croak 'Method "reset" not implemented by subclass' }
-sub retry_job  { croak 'Method "retry_job" not implemented by subclass' }
-sub stats      { croak 'Method "stats" not implemented by subclass' }
-sub unlock     { croak 'Method "unlock" not implemented by subclass' }
-
-sub unregister_worker {
-  croak 'Method "unregister_worker" not implemented by subclass';
-}
+sub broadcast         { croak 'Method "broadcast" not implemented by subclass' }
+sub dequeue           { croak 'Method "dequeue" not implemented by subclass' }
+sub enqueue           { croak 'Method "enqueue" not implemented by subclass' }
+sub fail_job          { croak 'Method "fail_job" not implemented by subclass' }
+sub finish_job        { croak 'Method "finish_job" not implemented by subclass' }
+sub history           { croak 'Method "history" not implemented by subclass' }
+sub list_jobs         { croak 'Method "list_jobs" not implemented by subclass' }
+sub list_locks        { croak 'Method "list_locks" not implemented by subclass' }
+sub list_workers      { croak 'Method "list_workers" not implemented by subclass' }
+sub lock              { croak 'Method "lock" not implemented by subclass' }
+sub note              { croak 'Method "note" not implemented by subclass' }
+sub receive           { croak 'Method "receive" not implemented by subclass' }
+sub register_worker   { croak 'Method "register_worker" not implemented by subclass' }
+sub remove_job        { croak 'Method "remove_job" not implemented by subclass' }
+sub repair            { croak 'Method "repair" not implemented by subclass' }
+sub reset             { croak 'Method "reset" not implemented by subclass' }
+sub retry_job         { croak 'Method "retry_job" not implemented by subclass' }
+sub stats             { croak 'Method "stats" not implemented by subclass' }
+sub unlock            { croak 'Method "unlock" not implemented by subclass' }
+sub unregister_worker { croak 'Method "unregister_worker" not implemented by subclass' }
 
 1;
 
@@ -265,7 +258,7 @@ These options are currently available:
 
   before => 23
 
-List only jobs before this id. Note that this option is EXPERIMENTAL and might change without warning!
+List only jobs before this id. Note that this option is B<EXPERIMENTAL> and might change without warning!
 
 =item ids
 
@@ -277,7 +270,7 @@ List only jobs with these ids.
 
   notes => ['foo', 'bar']
 
-List only jobs with one of these notes. Note that this option is EXPERIMENTAL and might change without warning!
+List only jobs with one of these notes. Note that this option is B<EXPERIMENTAL> and might change without warning!
 
 =item queues
 
@@ -485,7 +478,7 @@ These options are currently available:
 
   before => 23
 
-List only workers before this id. Note that this option is EXPERIMENTAL and might change without warning!
+List only workers before this id. Note that this option is B<EXPERIMENTAL> and might change without warning!
 
 =item ids
 
