@@ -38,12 +38,11 @@ Minion::Iterator - Minion iterator
 
   use Minion::Iterator;
 
-  my $iter = Minion::Iterator->new(
-    minion  => $minion, options => {states => ['inactive']});
+  my $iter = Minion::Iterator->new(minion  => $minion, options => {states => ['inactive']});
 
 =head1 DESCRIPTION
 
-L<Minion::Iterator> is an iterator for L<Minion> listing methods. Note that this module is EXPERIMENTAL and might
+L<Minion::Iterator> is an iterator for L<Minion> listing methods. Note that this module is B<EXPERIMENTAL> and might
 change without warning!
 
 =head1 ATTRIBUTES
