@@ -1,6 +1,7 @@
 package Minion::Job;
 use Mojo::Base 'Mojo::EventEmitter';
 
+use Carp qw(croak);
 use Mojo::IOLoop;
 use POSIX qw(WNOHANG);
 
@@ -11,7 +12,8 @@ sub app { shift->minion->app }
 sub execute {
   my $self = shift;
   return eval {
-    $self->minion->tasks->{$self->emit('start')->task}->($self, @{$self->args});
+    my $task = $self->minion->tasks->{$self->emit('start')->task};
+    ref $task ? $self->$task(@{$self->args}) : $self->run(@{$self->args});
     !!$self->emit('finish');
   } ? undef : $@;
 }
@@ -28,14 +30,12 @@ sub finish {
   return $ok ? !!$self->emit(finished => $result) : undef;
 }
 
-sub info {
-  $_[0]->minion->backend->list_jobs(0, 1, {ids => [$_[0]->id]})->{jobs}[0];
-}
+sub info { $_[0]->minion->backend->list_jobs(0, 1, {ids => [$_[0]->id]})->{jobs}[0]; }
 
 sub is_finished {
   my $self = shift;
   return undef unless waitpid($self->{pid}, WNOHANG) == $self->{pid};
-  $self->_handle;
+  $self->_reap;
   return 1;
 }
 
@@ -49,7 +49,7 @@ sub note {
 sub perform {
   my $self = shift;
   waitpid $self->start->pid, 0;
-  $self->_handle;
+  $self->_reap;
 }
 
 sub pid { shift->{pid} }
@@ -61,6 +61,8 @@ sub retry {
   return $self->minion->backend->retry_job($self->id, $self->retries, @_);
 }
 
+sub run { croak 'Method "run" not implemented by subclass' }
+
 sub start {
   my $self = shift;
 
@@ -81,7 +83,7 @@ sub start {
 
 sub stop { shift->kill('KILL') }
 
-sub _handle {
+sub _reap {
   my $self = shift;
   $self->emit(reap => $self->{pid});
   $? ? $self->fail("Non-zero exit status (@{[$? >> 8]})") : $self->finish;
@@ -97,9 +99,14 @@ Minion::Job - Minion job
 
 =head1 SYNOPSIS
 
-  use Minion::Job;
+  package MyApp::Task::Foo;
+  use Mojo::Base 'Minion::Job';
 
-  my $job = Minion::Job->new(id => $id, minion => $minion, task => 'foo');
+  sub run {
+    my ($self, @args) = @_;
+
+    # Magic here! :)
+  }
 
 =head1 DESCRIPTION
 
@@ -513,6 +520,13 @@ Queue to put job in.
 
 =back
 
+=head2 run
+
+  $job->run(@args);
+
+Task to perform by this job. Meant to be overloaded in a subclass to create a custom task class. Note that this method
+is B<EXPERIMENTAL> and might change without warning!
+
 =head2 start
 
   $job = $job->start;
