@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::Minion::Admin;
 use Mojo::Base 'Mojolicious::Plugin';
 
-use Mojo::File 'path';
+use Mojo::File qw(path);
 
 sub register {
   my ($self, $app, $config) = @_;
@@ -43,26 +43,17 @@ sub _list_jobs {
   my $c = shift;
 
   my $v = $c->validation;
-  $v->optional('id');
+  $v->optional($_) for qw(id note queue task);
   $v->optional('limit')->num;
   $v->optional('offset')->num;
-  $v->optional('queue');
   $v->optional('state')->in(qw(active failed finished inactive));
-  $v->optional('task');
   my $options = {};
-  $v->is_valid($_) && ($options->{"${_}s"} = $v->every_param($_))
-    for qw(id queue state task);
+  $v->is_valid($_) && ($options->{"${_}s"} = $v->every_param($_)) for qw(id note queue state task);
   my $limit  = $v->param('limit')  || 10;
   my $offset = $v->param('offset') || 0;
 
   my $results = $c->minion->backend->list_jobs($offset, $limit, $options);
-  $c->render(
-    'minion/jobs',
-    jobs   => $results->{jobs},
-    total  => $results->{total},
-    limit  => $limit,
-    offset => $offset
-  );
+  $c->render('minion/jobs', jobs => $results->{jobs}, total => $results->{total}, limit => $limit, offset => $offset);
 }
 
 sub _list_locks {
@@ -114,8 +105,7 @@ sub _manage_jobs {
 
   my $v = $c->validation;
   $v->required('id');
-  $v->required('do')
-    ->in('remove', 'retry', 'sig_int', 'sig_usr1', 'sig_usr2', 'stop');
+  $v->required('do')->in('remove', 'retry', 'sig_int', 'sig_usr1', 'sig_usr2', 'stop');
 
   $c->redirect_to('minion_jobs') if $v->has_error;
 
@@ -194,8 +184,7 @@ Mojolicious::Plugin::Minion::Admin - Admin UI
 
 =head1 DESCRIPTION
 
-L<Mojolicious::Plugin::Minion::Admin> is a L<Mojolicious> plugin providing an
-admin ui for the L<Minion> job queue.
+L<Mojolicious::Plugin::Minion::Admin> is a L<Mojolicious> plugin providing an admin ui for the L<Minion> job queue.
 
 =head1 OPTIONS
 
@@ -213,13 +202,13 @@ Name of route or path to return to when leaving the admin ui, defaults to C</>.
   # Mojolicious::Lite
   plugin 'Minion::Admin' => {route => app->routes->any('/admin')};
 
-L<Mojolicious::Routes::Route> object to attach the admin ui to, defaults to
-generating a new one with the prefix C</minion>.
+L<Mojolicious::Routes::Route> object to attach the admin ui to, defaults to generating a new one with the prefix
+C</minion>.
 
 =head1 METHODS
 
-L<Mojolicious::Plugin::Minion::Admin> inherits all methods from
-L<Mojolicious::Plugin> and implements the following new ones.
+L<Mojolicious::Plugin::Minion::Admin> inherits all methods from L<Mojolicious::Plugin> and implements the following new
+ones.
 
 =head2 register
 
